==> crawl_0.26.1.orig.tar.xz: stone_soup-0.26.1/source/zap-type.h <==
#pragma once

enum zap_type
{
    ZAP_THROW_FLAME,
    ZAP_THROW_FROST,
    ZAP_SLOW,
    ZAP_HASTE,
    ZAP_MAGIC_DART,
    ZAP_PARALYSE,
    ZAP_BOLT_OF_FIRE,
    ZAP_BOLT_OF_COLD,
    ZAP_CONFUSE,
    ZAP_INVISIBILITY,
    ZAP_DIG,
    ZAP_FIREBALL,
    ZAP_TELEPORT_OTHER,
    ZAP_LIGHTNING_BOLT,
    ZAP_POLYMORPH,
    ZAP_VENOM_BOLT,
    ZAP_BOLT_OF_DRAINING,
    ZAP_LEHUDIBS_CRYSTAL_SPEAR,
    ZAP_ENSLAVEMENT,
    ZAP_PAIN,
    ZAP_STICKY_FLAME,
    ZAP_STICKY_FLAME_RANGE,
    ZAP_DISPEL_UNDEAD,
    ZAP_BANISHMENT,
    ZAP_STING,
    ZAP_HURL_DAMNATION,
    ZAP_IRON_SHOT,
    ZAP_STONE_ARROW,
    ZAP_SHOCK,
    ZAP_ORB_OF_ELECTRICITY,
    ZAP_SPIT_POISON,
    ZAP_DEBUGGING_RAY,
    ZAP_BREATHE_FIRE,
    ZAP_BREATHE_FROST,
    ZAP_BREATHE_ACID,
    ZAP_BREATHE_POISON,
    ZAP_BREATHE_POWER,
    ZAP_AGONY,
    ZAP_DISINTEGRATE,
    ZAP_BREATHE_STEAM,
    ZAP_THROW_ICICLE,
    ZAP_CORONA,
    ZAP_HIBERNATION,
    ZAP_FLAME_TONGUE,
    ZAP_SANDBLAST,
    ZAP_BOLT_OF_MAGMA,
    ZAP_POISON_ARROW,
    ZAP_BREATHE_STICKY_FLAME,
    ZAP_PETRIFY,
    ZAP_PORKALATOR,
    ZAP_SLEEP,
    ZAP_PRIMAL_WAVE,
    ZAP_IOOD,
    ZAP_BREATHE_MEPHITIC,
    ZAP_INNER_FLAME,
    ZAP_FORCE_LANCE,
    ZAP_SEARING_RAY,
    ZAP_CRYSTAL_BOLT,
    ZAP_TUKIMAS_DANCE,
    ZAP_QUICKSILVER_BOLT,
    ZAP_CORROSIVE_BOLT,
    ZAP_RANDOM_BOLT_TRACER,
    ZAP_MEPHITIC,
    ZAP_UNRAVELLING,
    ZAP_ICEBLAST,
    ZAP_SLUG_DART,
    ZAP_BLINKBOLT,
    ZAP_FREEZING_BLAST, // monster freezing cloud (!?)
    ZAP_DIMENSION_ANCHOR,
    ZAP_VULNERABILITY,
    ZAP_SENTINEL_MARK,
    ZAP_SAP_MAGIC,
    ZAP_VIRULENCE,
    ZAP_DRAIN_MAGIC,
    ZAP_BECKONING,
    ZAP_FIRE_STORM,
    ZAP_MALMUTATE,
    ZAP_VILE_CLUTCH,
    ZAP_HARPOON_SHOT,
    ZAP_REFRIGERATE,
    ZAP_DRAIN_LIFE,
    ZAP_SONIC_WAVE,
    ZAP_THROW_PIE,
    ZAP_FOXFIRE,
    ZAP_AGONY_RANGE,
    ZAP_DISPEL_UNDEAD_RANGE,
    ZAP_TREMORSTONE,
    ZAP_NOXIOUS_CLOUD,
    ZAP_POISONOUS_CLOUD,
    ZAP_ENERGY_BOLT,
    ZAP_METAL_SPLINTERS,
    ZAP_SPLINTERSPRAY,
    ZAP_THORN_VOLLEY,
    ZAP_CALL_DOWN_DAMNATION,
    ZAP_MIASMA_BREATH,
    ZAP_PETRIFYING_CLOUD,
    ZAP_GHOSTLY_FIREBALL,
    ZAP_FLASH_FREEZE,
    ZAP_SPIT_LAVA,
    ZAP_THROW_BARBS,
    ZAP_HURL_SLUDGE,
    ZAP_HOLY_BREATH,
    ZAP_SPIT_ACID,
    ZAP_CHAOS_BREATH,
    ZAP_COLD_BREATH,
    ZAP_FIRE_BREATH,
    ZAP_SEARING_BREATH,
    ZAP_ELECTRICAL_BOLT,
    ZAP_FLAMING_CLOUD,
    ZAP_IGNITION,
    ZAP_HAILSTORM,
    ZAP_MYSTIC_BLAST,
    ZAP_SWORD_BEAM,
    NUM_ZAPS
};

==> crawl_0.27.1.orig.tar.xz: stone_soup-0.27.1/source/zap-type.h <==
#pragma once

enum zap_type
{
    ZAP_THROW_FLAME,
    ZAP_THROW_FROST,
    ZAP_SLOW,
    ZAP_HASTE,
    ZAP_MAGIC_DART,
    ZAP_PARALYSE,
    ZAP_BOLT_OF_FIRE,
    ZAP_BOLT_OF_COLD,
    ZAP_CONFUSE,
    ZAP_INVISIBILITY,
    ZAP_DIG,
    ZAP_FIREBALL,
    ZAP_TELEPORT_OTHER,
    ZAP_LIGHTNING_BOLT,
    ZAP_POLYMORPH,
    ZAP_VENOM_BOLT,
    ZAP_BOLT_OF_DRAINING,
    ZAP_LEHUDIBS_CRYSTAL_SPEAR,
    ZAP_CHARMING,
    ZAP_PAIN,
    ZAP_STICKY_FLAME,
    ZAP_STICKY_FLAME_RANGE,
    ZAP_DISPEL_UNDEAD,
    ZAP_BANISHMENT,
    ZAP_STING,
    ZAP_HURL_DAMNATION,
    ZAP_IRON_SHOT,
    ZAP_STONE_ARROW,
    ZAP_SHOCK,
    ZAP_ORB_OF_ELECTRICITY,
    ZAP_SPIT_POISON,
    ZAP_DEBUGGING_RAY,
    ZAP_BREATHE_FIRE,
    ZAP_BREATHE_FROST,
    ZAP_BREATHE_ACID,
    ZAP_BREATHE_POISON,
    ZAP_BREATHE_POWER,
    ZAP_AGONY,
    ZAP_MINDBURST,
    ZAP_BREATHE_STEAM,
    ZAP_THROW_ICICLE,
    ZAP_CORONA,
    ZAP_HIBERNATION,
    ZAP_FLAME_TONGUE,
    ZAP_SANDBLAST,
    ZAP_BOLT_OF_MAGMA,
    ZAP_POISON_ARROW,
    ZAP_BREATHE_STICKY_FLAME,
    ZAP_PETRIFY,
    ZAP_PORKALATOR,
    ZAP_SLEEP,
    ZAP_PRIMAL_WAVE,
    ZAP_IOOD,
    ZAP_BREATHE_MEPHITIC,
    ZAP_INNER_FLAME,
    ZAP_FORCE_LANCE,
    ZAP_SEARING_RAY,
    ZAP_CRYSTAL_BOLT,
    ZAP_TUKIMAS_DANCE,
    ZAP_QUICKSILVER_BOLT,
    ZAP_CORROSIVE_BOLT,
    ZAP_MEPHITIC,
    ZAP_UNRAVELLING,
    ZAP_ICEBLAST,
    ZAP_SLUG_DART,
    ZAP_BLINKBOLT,
    ZAP_FREEZING_BLAST, // monster freezing cloud (!?)
    ZAP_DIMENSION_ANCHOR,
    ZAP_VULNERABILITY,
    ZAP_SENTINEL_MARK,
    ZAP_SAP_MAGIC,
    ZAP_VIRULENCE,
    ZAP_DRAIN_MAGIC,
    ZAP_BECKONING,
    ZAP_FIRE_STORM,
    ZAP_MALMUTATE,
    ZAP_VILE_CLUTCH,
    ZAP_HARPOON_SHOT,
    ZAP_REFRIGERATE,
    ZAP_DRAIN_LIFE,
    ZAP_SONIC_WAVE,
    ZAP_THROW_PIE,
    ZAP_FOXFIRE,
    ZAP_AGONY_RANGE,
    ZAP_DISPEL_UNDEAD_RANGE,
    ZAP_TREMORSTONE,
    ZAP_NOXIOUS_CLOUD,
    ZAP_POISONOUS_CLOUD,
    ZAP_ENERGY_BOLT,
    ZAP_METAL_SPLINTERS,
    ZAP_SPLINTERSPRAY,
    ZAP_THORN_VOLLEY,
    ZAP_CALL_DOWN_DAMNATION,
    ZAP_MIASMA_BREATH,
    ZAP_PETRIFYING_CLOUD,
    ZAP_GHOSTLY_FIREBALL,
    ZAP_FLASH_FREEZE,
    ZAP_SPIT_LAVA,
    ZAP_THROW_BARBS,
    ZAP_HURL_SLUDGE,
    ZAP_HOLY_BREATH,
    ZAP_SPIT_ACID,
    ZAP_CHAOS_BREATH,
    ZAP_COLD_BREATH,
    ZAP_FIRE_BREATH,
    ZAP_SEARING_BREATH,
    ZAP_ELECTRICAL_BOLT,
    ZAP_FLAMING_CLOUD,
    ZAP_IGNITION,
    ZAP_HAILSTORM,
    ZAP_MYSTIC_BLAST,
    ZAP_SWORD_BEAM,
    ZAP_MIGHT,
    ZAP_VAMPIRIC_DRAINING,
    ZAP_CHAIN_LIGHTNING,
    ZAP_STUNNING_BURST,
    NUM_ZAPS
};
